# OBP_Reliability_Pillar

OBP_Reliability_Pillar package can be used to get the compliance details of Operational Best Practices for AWS Well Architected Reliability Pillar.

Release Notes:
# v0.0.4
1. Added Description column on Compliance Data set
2. Added method for S3 Bucket replication compliance
3. Fixes bugs
